@@ -15,21 +15,34 @@
 # You should have received a copy of the GNU General Public License
 # along with python-raven.  If not, see <http://www.gnu.org/licenses/>.
 
-from __future__ import unicode_literals
-
 """
 Raven
 
-The Raven module subclasses ucam_webauth.Request and ucam_webauth.Response
-in order to use the Raven URLs and the Raven response settings (default ptags,
-signing keys) respectively.
+The Raven module subclasses :class:`ucam_webauth.Request` and
+:class:`ucam_webauth.Response` in order to use the Raven URLs and the Raven
+response settings (default ptags and signing keys).
+
+.. data:: PUBKEY2
+
+    The key used to verify responses, from
+    `<https://raven.cam.ac.uk/project/keys/>`_
+
+.. data:: RAVEN_AUTH
+
+    The WLS' authentication start page:
+    ``RAVEN_AUTH.format(quoted_query_string)`` will produce a request
+
+.. data:: RAVEN_LOGOUT
+
+    The WLS' logout page: redirecting to this URL will log the user out of
+    Raven completely.
 
-Contains the Request and Response classes, and the RAVEN_LOGOUT constant
-(the url to redirect to in order to log out).
 """
 
+from __future__ import unicode_literals
+
 __name__ = "raven"
-__version__ = "0.1"
+__version__ = "0.3"
 __author__ = "Daniel Richman"
 __copyright__ = "Copyright 2013 Daniel Richman"
 __email__ = "main@danielrichman.co.uk"
@@ -57,14 +70,34 @@ RAVEN_LOGOUT = "https://raven.cam.ac.uk/auth/logout.html"
 
 
 class Request(ucam_webauth.Request):
-    """ucam_webauth.Request, configured for live Raven"""
+    """
+    :class:`ucam_webauth.Request`, configured for live Raven
+
+    Refer to :mod:`ucam_webauth` for documentation.
+
+    .. method:: __str__
+
+        Returns a full URL: the raven authentication url, with the query
+        string set to contain the request data
+
+    """
 
     def __str__(self):
         query_string = ucam_webauth.Request.__str__(self)
         return RAVEN_AUTH.format(query_string)
 
 class Response(ucam_webauth.Response):
-    """ucam_webauth.Response, configured for live Raven"""
+    """
+    :class:`ucam_webauth.Response`, configured for live Raven
+
+    Refer to :mod:`ucam_webauth` for documentation.
+
+    .. attribute:: keys
+
+        A single key; `kid` '2' maps to :data:`PUBKEY2`.
+
+    """
 
-    old_version_ptags = frozenset(["current"])
     keys = {"2": PUBKEY2}
+    #:
+    old_version_ptags = frozenset(["current"])
